@@ -120,6 +120,13 @@ class AboutDialog(QDialog):
                 '<br/> [it] Italian translation',
                 ''
             )
+            + QCoreApplication.translate(
+                '',
+                '<p>Masamichi Ito <a href="https://github.com/ito32bit">'
+                'https://github.com/ito32bit</a>'
+                '<br/> [ja] Japanese translation',
+                ''
+            )
             + QCoreApplication.translate(
                 '',
                 '<p>Heimen Stoffels '
@@ -137,6 +144,14 @@ class AboutDialog(QDialog):
                 '<br/> [pl] Polish translation',
                 ''
             )
+            + QCoreApplication.translate(
+                '',
+                '<p>Adrian Moise'
+                '<a href="mailto:sah.mat.ro@gmail.com">sah.mat.ro@gmail.com</a>'
+                '<br/> [ro] Romanian translation',
+                ''
+            )
+
             + QCoreApplication.translate(
                 '',
                 '<p>Artem Vorotnikov '
