@@ -5,11 +5,11 @@ import glob
 from PyQt5.QtCore import (
     QCoreApplication, QLocale, QSettings, QSize, Qt, pyqtSignal
 )
-from PyQt5.QtGui import QIcon
+from PyQt5.QtGui import QIcon, QColor, QFont
 from PyQt5.QtWidgets import (
     QCheckBox, QColorDialog, QComboBox, QDialog, QDialogButtonBox,
     QGridLayout, QHBoxLayout, QLabel, QLineEdit, QPushButton, QSpinBox,
-    QVBoxLayout
+    QVBoxLayout, QFontDialog
 )
 
 try:
@@ -330,6 +330,52 @@ class MeteoSettings(QDialog):
         self.comboBox_icons_theme.currentIndexChanged.connect(self.system_theme_icons)
         self.comboBox_icons_theme_changed = False
 
+        # Tray icon initialization size and temp position
+        self.tray_icon_init_label = QLabel(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Tray icon size and text position',
+                'This option concernes 2 dropdown lists'
+                'to define the size to initialize the tray icon'
+                'and the position of the temperature text in the icon'
+            )
+        )
+        self.tray_icon_init_label.setToolTip(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Changing this setting you can improve the displaying of the temperature in the tray icon',
+                'ToolTip of the label "Tray icon size and text position"'
+            )
+        )
+
+        self.tray_icon_init_cmb = QComboBox()
+        self.tray_icon_init_cmb.setToolTip(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Tray icon initialization size (default size: 64x64)',
+                'Tooltip of the drowndrop list with icon sizes'
+            )
+        )
+        self.tray_icon_init_cmb.addItems(["16x16", "24x24", "32x32", "64x64"])
+        icon_init_size = self.settings.value('Tray_icon_init_size') or '64x64'
+        self.tray_icon_init_cmb.setCurrentText(icon_init_size)
+        self.tray_icon_init_cmb.currentIndexChanged.connect(self.tray_icon_init_size_change)
+        self.tray_icon_init_cmb_changed = False
+
+        self.tray_icon_temp_pos_spinbox = QSpinBox()
+        self.tray_icon_temp_pos_spinbox.setRange(-20, 20)
+        temp_pos_in_icon = self.settings.value('Tray_icon_temp_position') or '-12'
+        self.tray_icon_temp_pos_spinbox.setValue(int(temp_pos_in_icon))
+        self.tray_icon_temp_pos_spinbox_changed = False
+        self.tray_icon_temp_pos_spinbox.valueChanged.connect(self.tray_icon_temp_pos_change)
+        self.tray_icon_temp_pos_spinbox.setToolTip(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Temperature position in the icon (vertically) (default value: -12)',
+                'ToolTip of the widget (a spinbox) to define the position of the temperature paint in the tray icon'
+            )
+        )
+
         # Toggle icon Temp
         self.toggle_tray_label = QLabel(
             QCoreApplication.translate(
@@ -354,35 +400,27 @@ class MeteoSettings(QDialog):
             )
         )
         self.activate_toggle_check()
-        # Font size
-        fontsize = self.settings.value('FontSize') or '18'
-        self.fontsize_label = QLabel(
+        # Font of temperature in tray
+        self.font_tray_changed = False
+        self.font_tray_conf_new = ''
+        self.font_tray_conf = self.settings.value('FontTray') or False
+        if not self.font_tray_conf:
+            self.font_tray_conf = 'Sans Serif,18,-1,5,50,0,0,0,0,0'
+            self.settings.setValue('FontTray', self.font_tray_conf)
+        self.font_tray_label = QLabel(
             QCoreApplication.translate(
                 'Settings dialogue',
-                'Font size in tray',
+                'Temperature font in system tray',
                 'Setting for the font size of the temperature in the tray icon'
             )
         )
-        self.fontsize_spinbox = QSpinBox()
-        self.fontsize_spinbox.setRange(12, 32)
-        self.fontsize_spinbox.setValue(int(fontsize))
-        if fontsize is None or fontsize == '':
-            self.settings.setValue('FontSize', '18')
-        self.fontsize_changed = False
-        self.fontsize_spinbox.valueChanged.connect(self.fontsize_change)
-        # Font weight
-        self.bold_checkbox = QCheckBox(
-            QCoreApplication.translate(
-                'Font setting - Checkbox label',
-                'Bold',
-                'Settings dialogue'
-            )
+        font_tray_btn_label = (
+            f"{self.font_tray_conf.split(',')[0]} - "
+            f"{self.font_tray_conf.split(',')[1]} - "
+            f"{self.font_tray_conf.split(',')[-1]}"
         )
-        bold_bool = self.settings.value('Bold') or 'False'
-        self.bold_bool = eval(bold_bool)
-        self.bold_checkbox.setChecked(self.bold_bool)
-        self.bold_checkbox.stateChanged.connect(self.bold)
-        self.bold_changed = False
+        self.font_tray_btn = QPushButton(font_tray_btn_label)
+        self.font_tray_btn.clicked.connect(self.getfont)
         # Proxy
         self.proxy_label = QLabel(
             QCoreApplication.translate(
@@ -422,8 +460,15 @@ class MeteoSettings(QDialog):
             )
         )
         self.owmkey_create.setOpenExternalLinks(True)
-        apikey = self.settings.value('APPID') or 'df1cc7dcbb602dbc33835dd2b89a3504'
+        apikey = self.settings.value('APPID') or 'ea2f2a2002635fd59dcd27be8aebb775'
         self.owmkey_text = QLineEdit()
+        self.owmkey_text.setToolTip(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'It is suggested to use a personal key.<br/>If someone hijacks the default meteo-qt key you will not be able to get the weather data (error 401 unauthorized)',
+                'Tooltip of the api key text field'
+            )
+        )
         self.owmkey_text.setText(apikey)
         self.owmkey_text.textChanged.connect(self.apikey_changed)
 
@@ -484,22 +529,24 @@ class MeteoSettings(QDialog):
         self.panel.addWidget(self.tray_icon_temp_label, 9, 0)
         self.panel.addWidget(self.tray_icon_combo, 9, 1)
         self.panel.addWidget(self.comboBox_icons_theme, 9, 2)
-        self.panel.addWidget(self.toggle_tray_label, 10, 0)
-        self.panel.addWidget(self.toggle_tray_spinbox, 10, 1)
-        self.panel.addWidget(self.toggle_tray_interval_label, 10, 2)
-        self.panel.addWidget(self.fontsize_label, 11, 0)
-        self.panel.addWidget(self.fontsize_spinbox, 11, 1)
-        self.panel.addWidget(self.bold_checkbox, 11, 2)
-        self.panel.addWidget(self.proxy_label, 12, 0)
-        self.panel.addWidget(self.proxy_chbox, 12, 1)
-        self.panel.addWidget(self.proxy_button, 12, 2)
-        self.panel.addWidget(self.owmkey_label, 13, 0)
-        self.panel.addWidget(self.owmkey_text, 13, 1)
-        self.panel.addWidget(self.owmkey_create, 13, 2)
-        self.panel.addWidget(self.start_minimized_label, 14, 0)
-        self.panel.addWidget(self.start_minimized_chbx, 14, 1)
-        self.panel.addWidget(self.logging_label, 15, 0)
-        self.panel.addWidget(self.logging_level_combo, 15, 1)
+        self.panel.addWidget(self.tray_icon_init_label, 10, 0)
+        self.panel.addWidget(self.tray_icon_init_cmb, 10, 1)
+        self.panel.addWidget(self.tray_icon_temp_pos_spinbox, 10, 2)
+        self.panel.addWidget(self.toggle_tray_label, 11, 0)
+        self.panel.addWidget(self.toggle_tray_spinbox, 11, 1)
+        self.panel.addWidget(self.toggle_tray_interval_label, 11, 2)
+        self.panel.addWidget(self.font_tray_label, 12, 0)
+        self.panel.addWidget(self.font_tray_btn, 12, 1)
+        self.panel.addWidget(self.proxy_label, 13, 0)
+        self.panel.addWidget(self.proxy_chbox, 13, 1)
+        self.panel.addWidget(self.proxy_button, 13, 2)
+        self.panel.addWidget(self.owmkey_label, 14, 0)
+        self.panel.addWidget(self.owmkey_text, 14, 1)
+        self.panel.addWidget(self.owmkey_create, 14, 2)
+        self.panel.addWidget(self.start_minimized_label, 15, 0)
+        self.panel.addWidget(self.start_minimized_chbx, 15, 1)
+        self.panel.addWidget(self.logging_label, 16, 0)
+        self.panel.addWidget(self.logging_level_combo, 16, 1)
 
         self.layout.addLayout(self.panel)
         self.layout.addLayout(self.buttonLayout)
@@ -643,7 +690,10 @@ class MeteoSettings(QDialog):
             return
 
     def color_chooser(self):
-        col = QColorDialog.getColor()
+        current_color = self.temp_tray_color
+        if hasattr(self, 'color_before'):
+            current_color = self.color_before
+        col = QColorDialog.getColor(QColor(current_color), self)
         if col.isValid():
             self.temp_colorButton.setStyleSheet(
                 'QWidget {{ background-color: {0} }}'.format(col.name())
@@ -655,6 +705,7 @@ class MeteoSettings(QDialog):
             self.color_before = col.name()
         else:
             logging.debug('Invalid color:' + str(col))
+            self.temp_color_resetButton.setFocus()
 
     def color_reset(self):
         self.temp_colorButton.setStyleSheet('QWidget { background-color:  }')
@@ -702,6 +753,21 @@ class MeteoSettings(QDialog):
         ]
         self.settings.setValue('TrayType', settray[0])
 
+    def tray_icon_init_size_change(self):
+        self.tray_icon_init_cmb_changed = True
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+
+    def tray_icon_init_size_apply(self):
+        self.settings.setValue('Tray_icon_init_size', self.tray_icon_init_cmb.currentText())
+
+    def tray_icon_temp_pos_change(self, pos):
+        self.tray_icon_temp_pos_spinbox_changed = True
+        self.tray_icon_temp_pos = pos
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+
+    def tray_icon_temp_pos_apply(self):
+        self.settings.setValue('Tray_icon_temp_position', str(self.tray_icon_temp_pos))
+
     def toggle_tray_interval_change(self, interval):
         self.toggle_tray_spinbox_changed = True
         self.toggle_tray_interval = interval
@@ -710,14 +776,28 @@ class MeteoSettings(QDialog):
     def toggle_tray_interval_apply(self):
         self.settings.setValue('Toggle_tray_interval', str(self.toggle_tray_interval))
 
-    def fontsize_change(self, size):
-        self.fontsize_changed = True
-        self.fontsize_value = size
-        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+    def getfont(self):
+        if self.font_tray_conf_new != "":
+            current_font = self.font_tray_conf_new
+        else:
+            current_font = self.font_tray_conf
+        ff = QFont()
+        ff.fromString(current_font)
+        font, ok = QFontDialog.getFont(ff, self)
+        if ok and font.toString() != self.font_tray_conf:
+            self.font_tray_changed = True
+            self.font_tray_conf_new = font.toString()
+            self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+            font_tray_btn_label = (
+                f"{self.font_tray_conf_new.split(',')[0]} - "
+                f"{self.font_tray_conf_new.split(',')[1]} - "
+                f"{self.font_tray_conf_new.split(',')[-1]}"
+            )
+            self.font_tray_btn.setText(font_tray_btn_label)
 
-    def fontsize_apply(self):
-        logging.debug('Apply fontsize: ' + str(self.fontsize_value))
-        self.settings.setValue('FontSize', str(self.fontsize_value))
+    def font_tray_apply(self):
+        logging.debug(f'Apply font for tray: {self.font_tray_conf_new}')
+        self.settings.setValue('FontTray', self.font_tray_conf_new)
 
     def system_theme_icons(self):
         self.comboBox_icons_theme_changed = True
@@ -729,18 +809,6 @@ class MeteoSettings(QDialog):
         else:
             self.settings.setValue('IconsTheme', self.comboBox_icons_theme.currentText())
 
-    def bold(self, state):
-        self.bold_state = state
-        self.bold_changed = True
-        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
-
-    def bold_apply(self):
-        if self.bold_state == 2:
-            bold = 'True'
-        else:
-            bold = 'False'
-        self.settings.setValue('Bold', str(bold))
-
     def start_minimized(self, state):
         self.start_minimized_state = state
         self.start_minimized_changed = True
@@ -867,12 +935,14 @@ class MeteoSettings(QDialog):
             self.notifier_apply()
         if self.tray_changed:
             self.tray_apply()
+        if self.tray_icon_init_cmb_changed:
+            self.tray_icon_init_size_apply()
+        if self.tray_icon_temp_pos_spinbox_changed:
+            self.tray_icon_temp_pos_apply()
         if self.toggle_tray_spinbox_changed:
             self.toggle_tray_interval_apply()
-        if self.fontsize_changed:
-            self.fontsize_apply()
-        if self.bold_changed:
-            self.bold_apply()
+        if self.font_tray_changed:
+            self.font_tray_apply()
         if self.comboBox_icons_theme_changed:
             self.system_icontheme_apply()
         if self.start_minimized_changed:
